summaryrefslogtreecommitdiffstats
path: root/vendor/compiler_builtins/src/math.rs
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/compiler_builtins/src/math.rs')
-rw-r--r--vendor/compiler_builtins/src/math.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/vendor/compiler_builtins/src/math.rs b/vendor/compiler_builtins/src/math.rs
index 4ae174891..c64984e9e 100644
--- a/vendor/compiler_builtins/src/math.rs
+++ b/vendor/compiler_builtins/src/math.rs
@@ -106,10 +106,11 @@ no_mangle! {
fn truncf(x: f32) -> f32;
}
// only for the thumb*-none-eabi* targets and riscv32*-none-elf targets that lack the floating point instruction set
#[cfg(any(
all(target_arch = "arm", target_os = "none"),
- all(target_arch = "riscv32", not(target_feature = "f"), target_os = "none")
+ all(target_arch = "riscv32", not(target_feature = "f"), target_os = "none"),
+ all(target_arch = "x86_64", target_os = "none")
))]
no_mangle! {
fn fmin(x: f64, y: f64) -> f64;
@@ -106,10 +106,11 @@ no_mangle! {
fn truncf(x: f32) -> f32;
}
-// only for the thumb*-none-eabi* targets and riscv32*-none-elf targets that lack the floating point instruction set
+// only for the thumb*-none-eabi*, riscv32*-none-elf and x86_64-unknown-none targets that lack the floating point instruction set
#[cfg(any(
all(target_arch = "arm", target_os = "none"),